"use strict";
/*
 * Copyright 2014 Per Eckerdal
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const exec_1 = require("../interfaces/exec");
/**
 * This file is a runnable script that takes two command line arguments:
 *
 * 1) An absolute path to the test interface
 * 2) An absolute path to the suite file
 *
 * Its output is a list of the tests that are declared in the suite file,
 * in JSON format to stdout.
 */
function defined(t) {
    return Object.fromEntries(Object.entries(t).flatMap(([k, v]) => (v !== undefined ? [[k, v]] : [])));
}
function testsOfSuite(file, child, parentPath = [], properties = {}) {
    const { name, type, attributes, skipped, only, unstable } = child;
    if (attributes) {
        properties.attributes = Object.assign(Object.assign({}, properties.attributes), attributes);
    }
    if (type === 'test') {
        if (!name) {
            throw new Error(`Missing test name`);
        }
        const path = { file, path: [...parentPath, name] };
        return [Object.assign({ path, skipped, only, unstable }, defined(properties))];
    }
    if (type === 'suite') {
        const { contents = [] } = child;
        const path = name ? [...parentPath, name] : parentPath;
        return contents
            .map((child) => {
            const { skipped, only, unstable } = child;
            const { timeout = undefined, slow = undefined } = child.type === 'suite' ? child : {};
            return testsOfSuite(file, child, path, Object.assign({ skipped, only, unstable, timeout, slow }, defined(properties)));
        })
            .flat();
    }
    throw new Error(`Unrecognized suite type ${type}`);
}
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        const [testInterfacePath, testInterfaceParameter, testFile] = process.argv.slice(2);
        const suite = yield (0, exec_1.default)(testInterfacePath, testInterfaceParameter, testFile);
        console.log(JSON.stringify(testsOfSuite(testFile, suite)));
    });
}
main();
