import { BreadcrumbMessage, ErrorMessage, HookErrorMessage, TestErrorMessage } from './reporters/message';
export type ErrorLocation = Pick<TestErrorMessage, 'in'> | Pick<HookErrorMessage, 'in' | 'inName'>;
/**
 * Generates a (non-colored) human-readable string of where an error occured.
 * The input format is designed so that you can simply pass in a message of type
 * 'error' that was passed to a reporter.
 */
export declare function prettyErrorLocation(errLoc?: ErrorLocation): string;
/**
 * Generates a colored, non-indented, human readable description of a single
 * error, in the format it is given to reporters as a message of type 'error'.
 *
 * @param errorMessage The error message, as given to the reporter:
 *     {
 *       [in: test|beforeHook|afterHook|uncaught]
 *       stack: [error.stack]
 *     }
 */
export declare function prettyError(errorMessage?: Partial<ErrorMessage>): string;
/**
 * Generates a colored, non-indented, human readable description of a test
 * timeout, including when it happened.
 *
 * @param location Information about what part of the test timed out.
 *     The object should be of the form that prettyErrorLocation expects.
 */
export declare function prettyTimeout(errLoc?: ErrorLocation): string;
export declare function prettyBreadcrumb(breadcrumb: BreadcrumbMessage, place?: string): string;
/**
 * Takes a string (possibly with newlines in it) and indents it with a given
 * number of spaces. Blank lines (for example the last line after an ending
 * newline) are not indented.
 *
 * @param str The string to indent
 * @param num The number of spaces to indent with
 */
export declare function indent(str: string, num?: number): string;
