"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = exports.SuiteContextImpl = void 0;
class SuiteContextImpl {
    constructor(_parentContext, attributes) {
        this._parentContext = _parentContext;
        this.attributes = attributes;
        this._parameters = {};
        this.before = global.before;
        this.after = global.after;
        this.beforeEach = global.beforeEach;
        this.afterEach = global.afterEach;
        this.describe = global.describe;
        this.it = global.it;
    }
    getParameters() {
        return this._parameters;
    }
    timeout(timeout) {
        var _a, _b, _c;
        if (timeout === undefined) {
            return (_c = (_a = this._parameters.timeout) !== null && _a !== void 0 ? _a : (_b = this._parentContext) === null || _b === void 0 ? void 0 : _b.timeout()) !== null && _c !== void 0 ? _c : null;
        }
        this._parameters.timeout = Number(timeout);
    }
    slow(slow) {
        var _a, _b, _c;
        if (slow === undefined) {
            return (_c = (_a = this._parameters.slow) !== null && _a !== void 0 ? _a : (_b = this._parentContext) === null || _b === void 0 ? void 0 : _b.slow()) !== null && _c !== void 0 ? _c : null;
        }
        this._parameters.slow = Number(slow);
    }
}
exports.SuiteContextImpl = SuiteContextImpl;
function skipFirstNLines(string, n) {
    return string.split(/\n/).splice(n).join('\n');
}
/**
 * Test context
 */
class Context {
    constructor(runtimeContext) {
        var _a;
        this.runtimeContext = runtimeContext;
        this.currentTest = this;
        this.title = (_a = runtimeContext === null || runtimeContext === void 0 ? void 0 : runtimeContext.getTitle().at(-1)) !== null && _a !== void 0 ? _a : '';
    }
    get attributes() {
        if (!this.runtimeContext) {
            throw new Error('Unexpected RuntimeContext access');
        }
        return this.runtimeContext.attributes;
    }
    fullTitle() {
        var _a, _b;
        return (_b = (_a = this.runtimeContext) === null || _a === void 0 ? void 0 : _a.getTitle().join(':')) !== null && _b !== void 0 ? _b : '';
    }
    timeout(ms) {
        var _a, _b;
        if (ms === undefined) {
            return (_a = this.runtimeContext) === null || _a === void 0 ? void 0 : _a.getTimeout();
        }
        (_b = this.runtimeContext) === null || _b === void 0 ? void 0 : _b.setTimeout(ms);
    }
    slow(ms) {
        var _a, _b;
        if (ms === undefined) {
            return (_a = this.runtimeContext) === null || _a === void 0 ? void 0 : _a.getSlowThreshold();
        }
        (_b = this.runtimeContext) === null || _b === void 0 ? void 0 : _b.setSlowThreshold(ms);
    }
    /**
     * Leave a breadcrumb to be printed in error for any failing assertions.
     */
    breadcrumb(messageOrError) {
        var _a, _b, _c;
        let message, trace;
        if (messageOrError instanceof Error) {
            message = messageOrError.message;
            trace = skipFirstNLines((_a = messageOrError.stack) !== null && _a !== void 0 ? _a : '', 1);
        }
        else {
            message = messageOrError;
            trace = skipFirstNLines((_b = new Error().stack) !== null && _b !== void 0 ? _b : '', 2);
        }
        (_c = this.runtimeContext) === null || _c === void 0 ? void 0 : _c.leaveBreadcrumb(message, trace);
    }
    /**
     * Emit debug information.
     */
    debugInfo(name, value) {
        var _a;
        (_a = this.runtimeContext) === null || _a === void 0 ? void 0 : _a.emitDebugInfo(name, value);
    }
}
exports.Context = Context;
