"use strict";
/*
 * Copyright 2014 Per Eckerdal
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _CancellableReporter_isFinished, _CancellableReporter_registerTestsCalled, _CancellableReporter_outstandingTests;
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * CancellableReporter is a reporter mainly for internal use by the suite runner. It
 * forwards all messages to another reporter, except for when it's been
 * "cancelled". When the CancellableReporter is cancelled, it will emit "aborted" finish
 * messages for all currently running tests and then ignore all subsequent
 * messages.
 *
 * This is used in the suite runner to be able to implement cancellation in a
 * nice way that doesn't require everything to know about cancellation.
 */
class CancellableReporter {
    constructor(reporter) {
        this.reporter = reporter;
        _CancellableReporter_isFinished.set(this, false);
        _CancellableReporter_registerTestsCalled.set(this, false);
        _CancellableReporter_outstandingTests.set(this, new Set());
    }
    registerTests(tests, options) {
        __classPrivateFieldSet(this, _CancellableReporter_registerTestsCalled, true, "f");
        !__classPrivateFieldGet(this, _CancellableReporter_isFinished, "f") && this.reporter.registerTests(tests, options);
    }
    registrationFailed(error) {
        !__classPrivateFieldGet(this, _CancellableReporter_isFinished, "f") && this.reporter.registrationFailed(error);
        __classPrivateFieldSet(this, _CancellableReporter_isFinished, true, "f");
    }
    gotMessage(testPath, message) {
        const key = JSON.stringify(testPath);
        if (message.type === 'start') {
            __classPrivateFieldGet(this, _CancellableReporter_outstandingTests, "f").add(key);
        }
        else if (message.type === 'finish') {
            __classPrivateFieldGet(this, _CancellableReporter_outstandingTests, "f").delete(key);
        }
        !__classPrivateFieldGet(this, _CancellableReporter_isFinished, "f") && this.reporter.gotMessage(testPath, message);
    }
    done() {
        !__classPrivateFieldGet(this, _CancellableReporter_isFinished, "f") && this.reporter.done();
        __classPrivateFieldSet(this, _CancellableReporter_isFinished, true, "f");
    }
    cancel() {
        __classPrivateFieldSet(this, _CancellableReporter_isFinished, true, "f");
        __classPrivateFieldGet(this, _CancellableReporter_outstandingTests, "f").forEach((key) => {
            const testPath = JSON.parse(key);
            this.reporter.gotMessage(testPath, { type: 'finish', result: 'aborted' });
        });
        __classPrivateFieldGet(this, _CancellableReporter_registerTestsCalled, "f") && this.reporter.done();
    }
    isFinished() {
        return __classPrivateFieldGet(this, _CancellableReporter_isFinished, "f");
    }
}
exports.default = CancellableReporter;
_CancellableReporter_isFinished = new WeakMap(), _CancellableReporter_registerTestsCalled = new WeakMap(), _CancellableReporter_outstandingTests = new WeakMap();
