"use strict";
/*
 * Copyright 2014 Per Eckerdal
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _MessageTracker_messages, _MessageTracker_didTimeOut;
Object.defineProperty(exports, "__esModule", { value: true });
function testPathToKey(testPath) {
    return JSON.stringify(testPath);
}
/**
 * MessageTracker is a very basic reporter (in the sense that it conforms to the
 * reporter interface) that does nothing but keep track of messages of a given type
 * that tests emit.
 *
 * It doesn't actually report anything anywhere but it exposes an accessor for
 * getting the relevant messages that a test has emitted so far.
 *
 * This is useful for example when not immediately showing errors or breadcrumbs for
 * tests.
 */
class MessageTracker {
    constructor(messageType) {
        this.messageType = messageType;
        _MessageTracker_messages.set(this, new Map());
        _MessageTracker_didTimeOut.set(this, new Set());
    }
    addMessage(testPath, message) {
        const key = testPathToKey(testPath);
        __classPrivateFieldGet(this, _MessageTracker_messages, "f").set(key, [...this.getMessages(testPath), message]);
    }
    testTimedOut(testPath) {
        return __classPrivateFieldGet(this, _MessageTracker_didTimeOut, "f").has(testPathToKey(testPath));
    }
    getMessages(testPath) {
        var _a;
        const key = testPathToKey(testPath);
        return (_a = __classPrivateFieldGet(this, _MessageTracker_messages, "f").get(key)) !== null && _a !== void 0 ? _a : [];
    }
    gotMessage(testPath, message) {
        if (message.type === this.messageType) {
            if (!this.testTimedOut(testPath)) {
                this.addMessage(testPath, message);
            }
        }
        else if (message.type === 'timeout') {
            __classPrivateFieldGet(this, _MessageTracker_didTimeOut, "f").add(testPathToKey(testPath));
        }
        else if (message.type === 'retry') {
            const key = testPathToKey(testPath);
            __classPrivateFieldGet(this, _MessageTracker_messages, "f").set(key, []);
            __classPrivateFieldGet(this, _MessageTracker_didTimeOut, "f").delete(key);
        }
    }
}
exports.default = MessageTracker;
_MessageTracker_messages = new WeakMap(), _MessageTracker_didTimeOut = new WeakMap();
