"use strict";
/*
 * Copyright 2014 Per Eckerdal
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _PhaseTracker_prevPhase, _PhaseTracker_didTimeOut;
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * PhaseTracker is a very basic reporter (in the sense that it conforms to the
 * reporter interface) that does nothing but keep track of where a test was
 * last (ie which hook it was in or if it was in the test).
 *
 * It doesn't actually report anything anywhere but it exposes an accessor for
 * getting the last phase of a test.
 *
 * This is useful when showing error messages for tests that time out: It is
 * helpful to say what timed out.
 */
class PhaseTracker {
    constructor() {
        _PhaseTracker_prevPhase.set(this, new Map());
        _PhaseTracker_didTimeOut.set(this, new Set());
    }
    gotMessage(testPath, message) {
        const key = JSON.stringify(testPath);
        if (message.type === 'retry') {
            __classPrivateFieldGet(this, _PhaseTracker_prevPhase, "f").delete(key);
            __classPrivateFieldGet(this, _PhaseTracker_didTimeOut, "f").delete(key);
        }
        else if (message.type === 'timeout') {
            __classPrivateFieldGet(this, _PhaseTracker_didTimeOut, "f").add(key);
        }
        else if (__classPrivateFieldGet(this, _PhaseTracker_didTimeOut, "f").has(key)) {
            // Do nothing; if the test timed out, we don't want to store any more.
            // Otherwise we will always report that the test timed out in after
            // hooks, even though that might not be the case.
        }
        else if (message.type === 'startedBeforeHook') {
            __classPrivateFieldGet(this, _PhaseTracker_prevPhase, "f").set(key, { in: 'beforeHook', inName: message.name });
        }
        else if (message.type === 'startedTest') {
            __classPrivateFieldGet(this, _PhaseTracker_prevPhase, "f").set(key, { in: 'test' });
        }
        else if (message.type === 'startedAfterHook') {
            __classPrivateFieldGet(this, _PhaseTracker_prevPhase, "f").set(key, { in: 'afterHook', inName: message.name });
        }
    }
    getLastPhase(path) {
        return __classPrivateFieldGet(this, _PhaseTracker_prevPhase, "f").get(JSON.stringify(path));
    }
}
exports.default = PhaseTracker;
_PhaseTracker_prevPhase = new WeakMap(), _PhaseTracker_didTimeOut = new WeakMap();
