import TestCount from '../test_count';
import { TestPath } from '../test_path';
import Combined from './combined';
import { FinishMessage, Message } from './message';
import Reporter, { RegisterOptions } from './reporter';
/**
 * SuiteMarker is a reporter that emits extra messages that contain information
 * about when a test suite has started and when it is finished. Before any test
 * that is within a suite (direct child or ancestor) runs, a 'suiteStart'
 * message is emitted. After the last test in a suite has run, a 'suiteFinish'
 * message is emitted. The messages are emitted with suite path and have the
 * format
 *
 *   { "type": ["suiteStart"|"suiteFinish"], "suite": [suite path] }
 *
 * Suites that don't have any tests are not reported.
 *
 * The SuiteMarker reporter can be run directly, but I expect it to most often
 * be used together with the Serializer reporter; that way, the receiving
 * reporter will get messages as if the tests are run serially and with
 * information about when suites start and end.
 */
export default class SuiteMarker<T extends FinishMessage> extends Combined<Message<T>> {
    _totalTests: TestCount;
    _remainingTests: TestCount;
    constructor(reporter: Reporter<Message<T>>);
    private maybeEmitSuiteStart;
    private maybeEmitSuiteFinish;
    registerTests(tests: TestPath[], opts: RegisterOptions, time: Date): void;
    gotMessage(testPath: TestPath, message: Message<T>, time: Date): void;
}
