"use strict";
/*
 * Copyright 2014 Per Eckerdal
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _TestCount_testCounts;
Object.defineProperty(exports, "__esModule", { value: true });
const test_path_util_1 = require("./test_path_util");
function incrementValue(obj, key, by = 1) {
    var _a;
    obj[key] = ((_a = obj[key]) !== null && _a !== void 0 ? _a : 0) + by;
}
/**
 * Test count is a helper class that operates on test paths and helps you to
 * keep track of how many tests there are in a given suite, including its
 * subsuites.
 *
 * Conceptually, TestCount is a set of test paths. You can add and remove tests
 * paths to the set, and you can query the set for how many tests there are in
 * a given suite.
 *
 * This is useful for example when you need to count remaining tests.
 */
class TestCount {
    constructor() {
        // Map from serialized suite path to the number of tests that are remaining in
        // that suite, including non-direct descendants. (Suite path is simply a test
        // path without the test included).
        _TestCount_testCounts.set(this, {});
    }
    /**
     * For a given suite path, increment the number of tests in it and its ancestors
     * by a given amount.
     */
    incrementValueForSuitePath(suitePath, by) {
        if (suitePath === null) {
            return;
        }
        incrementValue(__classPrivateFieldGet(this, _TestCount_testCounts, "f"), JSON.stringify(suitePath), by);
        this.incrementValueForSuitePath((0, test_path_util_1.suitePathOf)(suitePath), by);
    }
    addTest(testPath) {
        this.incrementValueForSuitePath((0, test_path_util_1.suitePathOf)(testPath));
    }
    /**
     * Helper method that is like addTest but it takes an array of test paths and
     * adds all of them.
     */
    addTests(testPaths) {
        testPaths.forEach((testPath) => this.addTest(testPath));
    }
    removeTest(testPath) {
        this.incrementValueForSuitePath((0, test_path_util_1.suitePathOf)(testPath), -1);
    }
    numberOfTestsInSuite(suitePath) {
        var _a;
        return (_a = __classPrivateFieldGet(this, _TestCount_testCounts, "f")[JSON.stringify(suitePath)]) !== null && _a !== void 0 ? _a : 0;
    }
}
exports.default = TestCount;
_TestCount_testCounts = new WeakMap();
