"use strict";
/*
 * Copyright 2014 Per Eckerdal
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var _TimeoutTimer_clock, _TimeoutTimer_startTime, _TimeoutTimer_setTimeout, _TimeoutTimer_clearTimeout, _TimeoutTimer_timeoutToken;
Object.defineProperty(exports, "__esModule", { value: true });
exports.FakeTimer = void 0;
const events_1 = require("events");
class FakeTimer extends events_1.EventEmitter {
    constructor(cancel = () => { }) {
        super();
        this.cancel = cancel;
        this.updates = [];
    }
    updateTimeout(t) {
        this.updates.push(t);
    }
}
exports.FakeTimer = FakeTimer;
/**
 * TimeoutTimer is a class that sets a timer similarly to setTimeout. The
 * difference is that TimeoutTimer also supports changing the timeout while
 * it's running. This is used for test timeouts; the tests can change their
 * own timeout while they are run. (Yes, this is a bit crazy, but I want to
 * be mocha compatible.)
 *
 * TimeoutTimer is an EventEmitter and will emit a 'timeout' message when the
 * time is up.
 *
 * @param timeout The timeout in milliseconds
 * @param options For testing purposes and other customization, it's possible
 *     to inject non-standard means of measuring time and setting timeouts.
 *     {
 *       clock: [function that returns the current time as a Date object],
 *       setTimeout: [set a timeout. Same signature as Javascript's setTimeout.
 *         Rhis function should always invoke its callback asynchronously],
 *       clearTimeout: [cancel a timeout. Same signature as Javascript's clearTimeout]
 *     }
 *     Optional.
 */
class TimeoutTimer extends events_1.EventEmitter {
    constructor(timeout, _a = {}) {
        var _b, _c;
        var { clock = () => Date.now() } = _a, opts = __rest(_a, ["clock"]);
        super();
        this.timeout = timeout;
        _TimeoutTimer_clock.set(this, void 0);
        _TimeoutTimer_startTime.set(this, void 0);
        _TimeoutTimer_setTimeout.set(this, void 0);
        _TimeoutTimer_clearTimeout.set(this, void 0);
        _TimeoutTimer_timeoutToken.set(this, null);
        __classPrivateFieldSet(this, _TimeoutTimer_clock, clock, "f");
        __classPrivateFieldSet(this, _TimeoutTimer_startTime, __classPrivateFieldGet(this, _TimeoutTimer_clock, "f").call(this), "f");
        __classPrivateFieldSet(this, _TimeoutTimer_setTimeout, (_b = opts.setTimeout) !== null && _b !== void 0 ? _b : setTimeout, "f");
        __classPrivateFieldSet(this, _TimeoutTimer_clearTimeout, (_c = opts.clearTimeout) !== null && _c !== void 0 ? _c : clearTimeout, "f");
        this.armTimeout();
    }
    timedOut() {
        __classPrivateFieldSet(this, _TimeoutTimer_timeoutToken, null, "f");
        this.emit('timeout', this.timeout);
    }
    /**
     * Calculate the remaining time for this timeout. May return a negative number.
     */
    remainingTime() {
        return this.timeout - (__classPrivateFieldGet(this, _TimeoutTimer_clock, "f").call(this) - __classPrivateFieldGet(this, _TimeoutTimer_startTime, "f"));
    }
    armTimeout() {
        if (__classPrivateFieldGet(this, _TimeoutTimer_timeoutToken, "f") !== null) {
            __classPrivateFieldGet(this, _TimeoutTimer_clearTimeout, "f").call(this, __classPrivateFieldGet(this, _TimeoutTimer_timeoutToken, "f"));
        }
        const remainingTime = this.remainingTime();
        if (remainingTime > 0) {
            __classPrivateFieldSet(this, _TimeoutTimer_timeoutToken, __classPrivateFieldGet(this, _TimeoutTimer_setTimeout, "f").call(this, () => this.timedOut(), remainingTime), "f");
        }
        else {
            process.nextTick(() => this.timedOut());
        }
    }
    /**
     * Change the timeout of this object. The timeout is relative from when the
     * timer was created. Setting the timeout to a time that has already passed
     * causes the timer to elapse immediately (on the next tick).
     */
    updateTimeout(timeout) {
        if (__classPrivateFieldGet(this, _TimeoutTimer_timeoutToken, "f") === null) {
            throw new Error('Cannot updateTimeout on timer that has elapsed');
        }
        this.timeout = timeout;
        this.armTimeout();
    }
    /**
     * Cancel the timer.
     */
    cancel() {
        __classPrivateFieldGet(this, _TimeoutTimer_timeoutToken, "f") != null && __classPrivateFieldGet(this, _TimeoutTimer_clearTimeout, "f").call(this, __classPrivateFieldGet(this, _TimeoutTimer_timeoutToken, "f"));
        __classPrivateFieldSet(this, _TimeoutTimer_timeoutToken, null, "f");
    }
}
exports.default = TimeoutTimer;
_TimeoutTimer_clock = new WeakMap(), _TimeoutTimer_startTime = new WeakMap(), _TimeoutTimer_setTimeout = new WeakMap(), _TimeoutTimer_clearTimeout = new WeakMap(), _TimeoutTimer_timeoutToken = new WeakMap();
